==> lib-colorifium-0.2.2.tgz: package/converters/rgbf.js <==
import { HueHelper, XYZHelper } from '../util/helpers';
import { Matrix } from '../util/matrix';
/**
 * Converter from float number RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export class FromRGBF {
    static toRGB8(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        return {
            r: Math.round(args.r * 255),
            g: Math.round(args.g * 255),
            b: Math.round(args.b * 255)
        };
    }
    static toHSL(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const basis = HueHelper.calculateBasisFromRGBF(args);
        const l = (basis.max + basis.min) / 2;
        let s;
        if (basis.delta === 0) {
            s = 0;
        }
        else {
            s = l < 0.5 ? basis.delta / (basis.max + basis.min) : basis.delta / (2 - basis.max - basis.min);
        }
        return {
            h: basis.hue,
            s: s,
            l: l
        };
    }
    static toHSV(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const basis = HueHelper.calculateBasisFromRGBF(args);
        return {
            h: basis.hue,
            s: basis.max === 0 ? 0 : basis.delta / basis.max,
            v: basis.max
        };
    }
    static toXYZ(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const pr = XYZHelper.pivotRGB(args.r);
        const pg = XYZHelper.pivotRGB(args.g);
        const pb = XYZHelper.pivotRGB(args.b);
        return {
            x: pr * Matrix.sRGBtoXYZ.r[0] + pg * Matrix.sRGBtoXYZ.r[1] + pb * Matrix.sRGBtoXYZ.r[2],
            y: pr * Matrix.sRGBtoXYZ.g[0] + pg * Matrix.sRGBtoXYZ.g[1] + pb * Matrix.sRGBtoXYZ.g[2],
            z: pr * Matrix.sRGBtoXYZ.b[0] + pg * Matrix.sRGBtoXYZ.b[1] + pb * Matrix.sRGBtoXYZ.b[2]
        };
    }
    static resolveArguments(r, g, b) {
        const argumentType = typeof r;
        let result;
        if (argumentType === 'object' && r !== null) {
            result = { r: r.r, g: r.g, b: r.b };
        }
        else if (argumentType === 'number') {
            result = { r: r, g: g, b: b };
        }
        else {
            throw new TypeError('Unknown arguments passed');
        }
        return result;
    }
}

==> lib-colorifium-0.4.1.tgz: package/converters/rgbf.js <==
import { HueHelper, XYZHelper } from '../util/helpers';
import { Matrix } from '../util/matrix';
import { FromXYZ } from './xyz';
/**
 * Converter from float number RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export class FromRGBF {
    static toRGB8(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        return {
            r: Math.round(args.r * 255),
            g: Math.round(args.g * 255),
            b: Math.round(args.b * 255)
        };
    }
    static toHSL(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const basis = HueHelper.calculateBasisFromRGBF(args);
        const l = (basis.max + basis.min) / 2;
        let s;
        if (basis.delta === 0) {
            s = 0;
        }
        else {
            s = l < 0.5 ? basis.delta / (basis.max + basis.min) : basis.delta / (2 - basis.max - basis.min);
        }
        return {
            h: basis.hue,
            s: s,
            l: l
        };
    }
    static toHSV(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const basis = HueHelper.calculateBasisFromRGBF(args);
        return {
            h: basis.hue,
            s: basis.max === 0 ? 0 : basis.delta / basis.max,
            v: basis.max
        };
    }
    static toXYZ(r, g, b) {
        const args = FromRGBF.resolveArguments(r, g, b);
        const pr = XYZHelper.pivotRGB(args.r);
        const pg = XYZHelper.pivotRGB(args.g);
        const pb = XYZHelper.pivotRGB(args.b);
        return {
            x: pr * Matrix.sRGBtoXYZ.r[0] + pg * Matrix.sRGBtoXYZ.r[1] + pb * Matrix.sRGBtoXYZ.r[2],
            y: pr * Matrix.sRGBtoXYZ.g[0] + pg * Matrix.sRGBtoXYZ.g[1] + pb * Matrix.sRGBtoXYZ.g[2],
            z: pr * Matrix.sRGBtoXYZ.b[0] + pg * Matrix.sRGBtoXYZ.b[1] + pb * Matrix.sRGBtoXYZ.b[2]
        };
    }
    static toLab(r, g, b) {
        return FromXYZ.toLab(FromRGBF.toXYZ(FromRGBF.resolveArguments(r, g, b)));
    }
    static resolveArguments(r, g, b) {
        const argumentType = typeof r;
        if (argumentType === 'object' && r !== null) {
            return { r: r.r, g: r.g, b: r.b };
        }
        if (argumentType === 'number') {
            return { r: r, g: g, b: b };
        }
        throw new TypeError('Unknown arguments passed');
    }
}
